@@ -1,11 +1,11 @@
 /* String search routines for GNU Emacs.
-   Copyright (C) 1985, 1986, 1987 Free Software Foundation, Inc.
+   Copyright (C) 1985, 1986, 1987, 1992 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
 
 GNU Emacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 1, or (at your option)
+the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
 GNU Emacs is distributed in the hope that it will be useful,
@@ -31,7 +31,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #  define BufferSafeCeiling(n) BUFFER_CEILING_OF(n)
 #  define BufferSafeFloor(n) BUFFER_FLOOR_OF(n)
 # else
-#  error "you lose"
+   ERROR!  You lose.
 # endif
 #endif
 
